Package: dynaTree
Title: Dynamic Trees for Learning and Design
Version: 1.2-16
Date: 2023-08-22
Author: Robert B. Gramacy <rbg@vt.edu>, Matt A. Taddy and Christoforos Anagnostopoulos
Depends: R (>= 2.14.0), methods
Suggests: interp, tgp, plgp, MASS
Description: Inference by sequential Monte Carlo for 
  dynamic tree regression and classification models
  with hooks provided for sequential design and optimization, 
  fully online learning with drift, variable selection, and 
  sensitivity analysis of inputs.  Illustrative 
  examples from the original dynamic trees paper 
  (Gramacy, Taddy & Polson (2011); <doi:10.1198/jasa.2011.ap09769>) are facilitated
  by demos in the package; see demo(package="dynaTree").
Maintainer: Robert B. Gramacy  <rbg@vt.edu>
License: LGPL
URL: https://bobby.gramacy.com/r_packages/dynaTree/
NeedsCompilation: yes
Packaged: 2023-08-22 13:43:34 UTC; bobby
Repository: CRAN
Date/Publication: 2023-08-23 07:10:02 UTC
Built: R 4.2.0; aarch64-apple-darwin20; 2023-08-27 02:23:25 UTC; unix
Archs: dynaTree.so.dSYM
