# Load the shared object
useDynLib(dynaTree, .registration=TRUE)

# Exports
export(alc, alc.dynaTree, alcX, alcX.dynaTree, deletecloud,
       deleteclouds, copy, copy.dynaTree, dynaTree,
       dynaTrees, getBF, rejuvenate, rejuvenate.dynaTree,
       relevance, relevance.dynaTree, retire, retire.dynaTree,
       sens, sens.dynaTree, treestats, treestats.dynaTree,
       alcalc, plotprogress, varpropuse, varpropuse.dynaTree,
       varproptotal, varproptotal.dynaTree, qEntropy, 
       qEntropy.dynaTree, qEI, qEI.dynaTree)

# Import all packages listed as Imports or Depends
import(
  methods
)

## required for new CRAN checks
importFrom("graphics", "abline", "hist", "lines", "par", "plot",
           "points")
importFrom("stats", "predict", "runif")

# S3
S3method(alc, dynaTree)
S3method(alcX, dynaTree)
S3method(copy, dynaTree)
S3method(plot, dynaTree)
S3method(predict, dynaTree)
S3method(coef, dynaTree)
S3method(rejuvenate, dynaTree)
S3method(relevance, dynaTree)
S3method(retire, dynaTree)
S3method(sens, dynaTree)
S3method(update, dynaTree)
S3method(varpropuse, dynaTree)
S3method(varproptotal, dynaTree)
S3method(qEntropy, dynaTree)
S3method(qEI, dynaTree)
